@@ -54,6 +54,9 @@ class PypiRepoSession(ProjectHolder):
         # we are in "enriching" project dict with desired version information
         # and return None if there's no matching version
         from .Version import Version
+        if self.project is None:
+            print("Project is not listed on PyPI")
+            return None
         if not major:
             latest_ver = self.project['info']['version']
             v = Version(latest_ver)
